==> cdktf-cdktf-provider-google-0.2.42.tar.gz: package/lib/healthcare-hl7-v2-store-iam-policy.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface HealthcareHl7V2StoreIamPolicyConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/healthcare_hl7_v2_store_iam_policy.html#hl7_v2_store_id HealthcareHl7V2StoreIamPolicy#hl7_v2_store_id}.
     *
     * @stability stable
     */
    readonly hl7V2StoreId: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/healthcare_hl7_v2_store_iam_policy.html#policy_data HealthcareHl7V2StoreIamPolicy#policy_data}.
     *
     * @stability stable
     */
    readonly policyData: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/google/r/healthcare_hl7_v2_store_iam_policy.html google_healthcare_hl7_v2_store_iam_policy}.
 *
 * @stability stable
 */
export declare class HealthcareHl7V2StoreIamPolicy extends cdktf.TerraformResource {
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/google/r/healthcare_hl7_v2_store_iam_policy.html google_healthcare_hl7_v2_store_iam_policy} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: HealthcareHl7V2StoreIamPolicyConfig);
    /**
     * @stability stable
     */
    get etag(): string;
    private _hl7V2StoreId;
    /**
     * @stability stable
     */
    get hl7V2StoreId(): string;
    /**
     * @stability stable
     */
    set hl7V2StoreId(value: string);
    /**
     * @stability stable
     */
    get hl7V2StoreIdInput(): string;
    /**
     * @stability stable
     */
    get id(): string;
    private _policyData;
    /**
     * @stability stable
     */
    get policyData(): string;
    /**
     * @stability stable
     */
    set policyData(value: string);
    /**
     * @stability stable
     */
    get policyDataInput(): string;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}

==> cdktf-cdktf-provider-google-0.3.169.tar.gz: package/lib/healthcare-hl7-v2-store-iam-policy.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface HealthcareHl7V2StoreIamPolicyConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/healthcare_hl7_v2_store_iam_policy.html#hl7_v2_store_id HealthcareHl7V2StoreIamPolicy#hl7_v2_store_id}.
     *
     * @stability stable
     */
    readonly hl7V2StoreId: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/healthcare_hl7_v2_store_iam_policy.html#policy_data HealthcareHl7V2StoreIamPolicy#policy_data}.
     *
     * @stability stable
     */
    readonly policyData: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/google/r/healthcare_hl7_v2_store_iam_policy.html google_healthcare_hl7_v2_store_iam_policy}.
 *
 * @stability stable
 */
export declare class HealthcareHl7V2StoreIamPolicy extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/google/r/healthcare_hl7_v2_store_iam_policy.html google_healthcare_hl7_v2_store_iam_policy} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: HealthcareHl7V2StoreIamPolicyConfig);
    /**
     * @stability stable
     */
    get etag(): string;
    private _hl7V2StoreId?;
    /**
     * @stability stable
     */
    get hl7V2StoreId(): string;
    /**
     * @stability stable
     */
    set hl7V2StoreId(value: string);
    /**
     * @stability stable
     */
    get hl7V2StoreIdInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _policyData?;
    /**
     * @stability stable
     */
    get policyData(): string;
    /**
     * @stability stable
     */
    set policyData(value: string);
    /**
     * @stability stable
     */
    get policyDataInput(): string | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
